==> vss-ui-4.141.4.tgz: package/Components/Tabs/TabGroupProviderContext.js <==
import * as tslib_1 from "tslib";
import * as React from "react";
export var TabGroupProviderContext = React.createContext({ groups: [] });
var TabGroupProvider = /** @class */ (function (_super) {
    tslib_1.__extends(TabGroupProvider, _super);
    function TabGroupProvider(props) {
        var _this = _super.call(this, props) || this;
        _this.onGroupsChanged = function (event) {
            var _a;
            (_a = _this.groups).push.apply(_a, event.addedItems);
            _this.groups = _this.groups.sort(function (a, b) { return (a.order || 100) - (b.order || 100); });
            _this.forceUpdate();
        };
        _this.groups = [];
        _this.observableArrays = [];
        props.providers && props.providers.forEach(function (provider) {
            var _a;
            var observableArray = provider.getItems();
            _this.observableArrays.push(observableArray);
            (_a = _this.groups).push.apply(_a, observableArray.items);
        });
        _this.groups = _this.groups.sort(function (a, b) { return (a.order || 100) - (b.order || 100); });
        return _this;
    }
    TabGroupProvider.prototype.render = function () {
        return React.createElement(TabGroupProviderContext.Provider, { value: { groups: this.groups } }, this.props.children);
    };
    TabGroupProvider.prototype.componentDidMount = function () {
        var _this = this;
        this.observableArrays.forEach(function (observableArray) { return observableArray.subscribe(_this.onGroupsChanged); });
    };
    TabGroupProvider.prototype.componentWillUnmount = function () {
        var _this = this;
        this.observableArrays.forEach(function (observableArray) { return observableArray.unsubscribe(_this.onGroupsChanged); });
    };
    return TabGroupProvider;
}(React.Component));
export { TabGroupProvider };

==> vss-ui-4.142.1.tgz: package/Components/Tabs/TabGroupProviderContext.js <==
import * as tslib_1 from "tslib";
import * as React from "react";
export var TabGroupProviderContext = React.createContext({ groups: [] });
var TabGroupProvider = /** @class */ (function (_super) {
    tslib_1.__extends(TabGroupProvider, _super);
    function TabGroupProvider(props) {
        var _this = _super.call(this, props) || this;
        _this.onGroupsChanged = function (event) {
            var _a;
            (_a = _this.groups).push.apply(_a, event.addedItems);
            _this.groups = _this.groups.sort(function (a, b) { return (a.order || 100) - (b.order || 100); });
            _this.forceUpdate();
        };
        _this.groups = [];
        _this.observableArrays = [];
        props.providers && props.providers.forEach(function (provider) {
            var _a;
            var observableArray = provider.getItems();
            _this.observableArrays.push(observableArray);
            (_a = _this.groups).push.apply(_a, observableArray.value);
        });
        _this.groups = _this.groups.sort(function (a, b) { return (a.order || 100) - (b.order || 100); });
        return _this;
    }
    TabGroupProvider.prototype.render = function () {
        return React.createElement(TabGroupProviderContext.Provider, { value: { groups: this.groups } }, this.props.children);
    };
    TabGroupProvider.prototype.componentDidMount = function () {
        var _this = this;
        this.observableArrays.forEach(function (observableArray) { return observableArray.subscribe(_this.onGroupsChanged); });
    };
    TabGroupProvider.prototype.componentWillUnmount = function () {
        var _this = this;
        this.observableArrays.forEach(function (observableArray) { return observableArray.unsubscribe(_this.onGroupsChanged); });
    };
    return TabGroupProvider;
}(React.Component));
export { TabGroupProvider };
